![logo](docs/source/_static/logo.svg)

[![PyPI - Version](https://img.shields.io/pypi/v/reprospect?color=blue)](https://pypi.org/project/reprospect/)
![PyPI - Wheel](https://img.shields.io/pypi/wheel/reprospect)
![PyPI - Implementation](https://img.shields.io/pypi/implementation/reprospect)

# reprospect

`ReProspect` provides a framework and tools for reproducible prospecting of CUDA applications.

See [the documentation](https://uliegecsm.github.io/reprospect/) for more information.
